@@ -1,4 +1,7 @@
 """Function used to extract package information from a local setup.py"""
+import os
+import sys
+
 
 def extract_setup_metadata():
     """Get all values of parameters passed to setup()"""
@@ -14,7 +17,12 @@ def extract_setup_metadata():
     setuptools.setup = on_setup_loaded
     distutils.core.setup = on_setup_loaded
 
+    # make sure we will be able to import setup from current directory
+    current_directory = os.getcwd()
+    sys.path.insert(0, current_directory)
+
     # import you setup.py with mocked setup()
+    print('Loading setup from directory', current_directory, file=sys.stderr)
     import setup
 
     return package_metadata
@@ -23,4 +31,6 @@ def extract_setup_metadata():
 def get_setup_metadata(key: str):
     """Get value of a specific parameter of setup()"""
     package_metadata = extract_setup_metadata()
-    return package_metadata[key]
+    value = package_metadata[key]
+    print(f'Value for key {key} in setup is {value}', file=sys.stderr)
+    return value
